Struct thread_db::Thread

source ·
pub struct Thread<'a> { /* private fields */ }
Represent linux lwp.

Implementations

Validate that TH is a thread handle.

Get address of the given module’s TLS storage area for the given thread. Note that for a given running process the module ID for the main executable will always be 1.

Get address of thread local variable. map_addr - address of module link_map struct.