pub struct Thread<'a> { /* private fields */ }
Validate that TH is a thread handle.
Get address of the given module’s TLS storage area for the given thread.
Note that for a given running process the module ID for the main executable will always be 1.
Get address of thread local variable.
map_addr - address of module link_map struct.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.